import sys
import re
import os
import json


lang = sys.argv[1]


def normalize(txt):
    txt = re.sub(r'\s*,\s*', ',', txt)
    txt = re.sub(r'\s*\.\s*', '.', txt)
    return txt


modes = ['train', 'val', 'test']

annotations = []
with open('annots/' + lang + '.json', 'r') as fp:
    lines = fp.readlines()
    annotations = map(lambda l: json.loads(l), lines)
    annotations = list(annotations)

translations = {}
for line in annotations:
    if line['content'].startswith('"'):
        line['content'] = line['content'][1:-1].replace('""', '"')
    splits = line['content'].split('|')
    if splits[1] in translations and translations[splits[1]] != splits[2]:
        raise Exception('Broke')
    translations[normalize(splits[1])] = splits[2]

os.makedirs(lang)

for mode in modes:
    with open('en/{}.jsonl'.format(mode), 'r') as fp:
        data = fp.readlines()
        tdata = []
        for line in data:
            try:
                inst = json.loads(line)
                tinst = {
                    'premise': translations[normalize(inst['premise'])],
                    'choice1': translations[normalize(inst['choice1'])],
                    'choice2': translations[normalize(inst['choice2'])],
                    'question': inst['question'],
                    'idx': inst['idx']
                }
                if mode != 'test':
                    tinst['label'] = inst['label']
            except:
                continue
            tdata.append(tinst)
    with open('{}/{}.jsonl'.format(lang, mode), 'w') as fp:
        for line in tdata:
            fp.write(json.dumps(line, ensure_ascii=False))
            fp.write('\n')
